require "spec_helper"

describe "Creating a new version" do

  GEM_BASE = File.join(File.dirname(__FILE__), "..")

  before(:all) do
    ENV["TEMPLATE"] = "./spec/support/sample-image.jpg"
    ENV["TARGET"]   = "./tmp/results"
  end

  after(:all) do
    FileUtils.rm_rf(File.join(GEM_BASE, "tmp", "results"))
  end

  let(:name) { "Test.png" }
  let(:scale)  { 2 }
  let(:size) { 100 }

  it "creates a new image file with the correct name" do
    Image.new(Size.new(name: name, scale: scale, size: size)).write!
    expect(File).to exist(File.join(GEM_BASE, "tmp", "results", name))
  end

  it "creates a file of the correct scale and size" do
    result = MiniMagick::Image.open(File.join(GEM_BASE, "tmp", "results", name))
    expect(result.width).to  eql(size * scale)
    expect(result.height).to eql(size * scale)
  end

  it "converts file to png" do
    result = MiniMagick::Image.open(File.join(GEM_BASE, "tmp", "results", name))
    expect(result.mime_type).to eql("image/jpeg")
  end

end